# ConfiGator

![Mr.ConfiGator himself](img/icon.png)

[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

[![Lint and Test](https://github.com/cmpsc-481-s22-m1/ConfiGator/actions/workflows/main.yml/badge.svg?branch=release%2F0.1.0)](https://github.com/cmpsc-481-s22-m1/ConfiGator/actions/workflows/main.yml)

A configuration file generator meant to be used with [GatorGradle](https://github.com/GatorEducator/gatorgradle).

## Overview

ConfiGator is a tool to be used in hand with GatorGradle to generate configuration
files for assignments that require GatorGradle. ConfiGator uses
[Poetry](https://python-poetry.org/) for package and dependency management.

## Usage

### Installing ConfiGator

Command to install ConfiGator

```bash
pipx install pyconfigator
```

* *if* `pipx` *does not work, use* `pip` *instead.*

### Running ConfiGator

Command to run ConfiGator (after installing using `pip` or `pipx`)

```bash
configator
```

### Command to Change Specific Configurations

The command below will show a list of every available command to change
specific configurations in `config/gatorgrader.yml` or `build.gradle`.

```bash
configator --help
```

### If you need Assistance

Create an issue or a discussion post for assistance if you encounter any issues
with ConfiGator.

### Contributors

* William Connelly, [@connellyw](https://github.com/connellyw)
* Kyrie Doniz, [@donizk](https://github.com/donizk)
* Kevin Lee, [@Kevin487](https://github.com/Kevin487)
* Peter Snipes, [@Peter-Snipes](https://github.com/Peter-Snipes)
* Kai'lani Woodard, [@kailaniwoodard](https://github.com/kailaniwoodard)
* Adam Shinomiya, [@TheShiny1](https://github.com/TheShiny1)
* Maria Kim Heinert, [@mariakimheinert](https://github.com/mariakimheinert)
* Saejin Heinert, [@Michionlion](https://github.com/Michionlion)
